@@ -10,13 +10,15 @@ import sys
 import pprint
 import tempfile
 import os
+import io
 from subprocess import Popen, PIPE
 
 from past import utils
 from past.builtins import basestring, str as oldstr, unicode
 
 from past.translation import install_hooks, remove_hooks, common_substring
-from future.tests.base import unittest, CodeHandler, skip26
+from future.tests.base import (unittest, CodeHandler, skip26,
+                               expectedFailurePY3, expectedFailurePY26)
 
 
 class TestTranslate(unittest.TestCase):
@@ -40,7 +42,10 @@ class TestTranslate(unittest.TestCase):
     def write_and_import(self, code, modulename='mymodule'):
         self.assertTrue('.py' not in modulename)
         filename = modulename + '.py'
-        with open(self.tempdir + filename, 'w') as f:
+        if isinstance(code, bytes):
+            code = code.decode('utf-8')
+        # Be explicit about encoding the temp file as UTF-8 (issue #63):
+        with io.open(self.tempdir + filename, 'w', encoding='utf-8') as f:
             f.write(textwrap.dedent(code).strip() + '\n')
 
         # meta_path_len = len(sys.meta_path)
@@ -78,7 +83,7 @@ class TestTranslate(unittest.TestCase):
         module = self.write_and_import(code, 'execer')
         self.assertEqual(module.x, 7)
         
-    @skip26
+    @expectedFailurePY3
     def test_div(self):
         code = """
         x = 3 / 2
@@ -86,8 +91,8 @@ class TestTranslate(unittest.TestCase):
         module = self.write_and_import(code, 'div')
         self.assertEqual(module.x, 1)
 
-    @skip26
-    @unittest.skipIf(utils.PY3, 'test_stdlib currently fails on Py3')
+    @expectedFailurePY26
+    @expectedFailurePY3
     def test_stdlib(self):
         """
         Have the old stdlib names been mapped onto the new ones?
@@ -118,6 +123,8 @@ class TestTranslate(unittest.TestCase):
         """
         module = self.write_and_import(code, 'future_standard_library')
         self.assertTrue('configparser' in dir(module))
+        from future import standard_library
+        standard_library.remove_hooks()
 
     def test_old_builtin_functions(self):
         code = """
@@ -148,8 +155,8 @@ class TestTranslate(unittest.TestCase):
         self.assertEqual(module.d, [0, 4, 8, 12, 16])
         self.assertTrue(module.e)
 
-    @skip26
-    # @unittest.expectedFailure
+    @expectedFailurePY26
+    @expectedFailurePY3
     def test_import_builtin_types(self):
         code = """
         s1 = 'abcd'
